-- 制作UI时，台子面居中，方便设置、计算点击区域
Lua_ExpeditionSingleItem = class("Lua_ExpeditionSingleItem", Lua_DisplayObject);
function Lua_ExpeditionSingleItem:ctor(p)
	self:superCall("ctor", p, "ExpeditionSingleItem_skin");
end

function Lua_ExpeditionSingleItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_ExpeditionSingleItem:dispose()
	if self.modelEffImg then
		self.modelEffImg:dispose();
		self.modelEffImg = nil;
	end
	self.data = nil;
	self.index = nil;
	self.eventData = nil;
	self:superCall("dispose");
end

-- 设置所在范围
function Lua_ExpeditionSingleItem:updateBound()
	local posX = self.posX == nil and 0 or self.posX;
	local posY = self.posY == nil and 0 or self.posY;
	local scaleX = self.scaleX == nil and 1 or self.scaleX;
	local scaleY = self.scaleY == nil and 1 or self.scaleY;
	self.minX = posX - self.width / 2 * scaleX;
	self.maxX = posX + self.width / 2 * scaleX;
	self.minY = posY - self.height / 2 * scaleY;
	self.maxY = posY + self.height / 2 * scaleY;
end

function Lua_ExpeditionSingleItem:setData(data, index)
	self.baseIcon:setEnable(true);
	self.path_1:setEnable(true);
	self.path_2:setEnable(true);
	self.arrow:setEnable(false);
	self:showIcon(nil)
	self:showModel(nil)
	self:showStar(0);

	self.data = data;
	self.index = index;
	self.canClick = false; -- 是否可点击
	self.canOperate = false; -- 是否可操作
	
	local eventId = DataCenter.expeditionData:getLatticeEvent(data.id, index);
	self.eventData = DataCenter.expeditionUtil:getLatticeInfo(eventId);
	if self.eventData == nil then
		return;
	end

	local bPass, passEventId = DataCenter.expeditionData:getLatticeState(data.id, index);
	local cur_stage = DataCenter.expeditionData.cur_stage;
	local cur_location = DataCenter.expeditionData.cur_location;
	local cur_state = DataCenter.expeditionData.cur_state;
	local cur_difficulty = DataCenter.expeditionData.cur_difficulty;
	local id, lattice = DataCenter.expeditionData:getModelPosInfo(); -- 浣熊站位
	if data.id == id and index == lattice then
		self:showModel("103000405_low")
	end

	if data.stage > 7 then
		self.baseIcon:setEnable(false);
		self.path_1:setEnable(false);
		self.path_2:setEnable(false);
		if not bPass then
			local canClick, canOperate, iconName, modelName, starNum = self:getInfo(data, index, self.eventData);
			self.canClick = canClick;
			self.canOperate = canOperate;
			self:showStar(starNum)
			if self.eventData.type == 7 then -- 全层奖励
				if cur_difficulty <= 0 then
					self:showIcon("ui_bjyz_icon_02")
				else
					self:showIcon("ui_bjyz_icon_03")
				end
			else
				if not strIsNullOrEmpty(iconName) then
					self:showIcon(iconName)
					self:showModel(nil)
				elseif not strIsNullOrEmpty(modelName) then
					self:showIcon(nil)
					self:showModel(modelName)
				else
					self:showIcon(nil)
					self:showModel(nil)
				end
			end
		end
		return;
	end

	-- 已通关
	if bPass then
		self.path_1:setEnable(false);
		self.path_2:setEnable(false);
		if eventId == passEventId then
			if data.stage == cur_stage then
				if data.stage == 7 then
					self.path_1:setEnable(not (index == 1));
					self.path_2:setEnable(not (index == 2));
				elseif data.map == 3 then
					self.path_1:setEnable(not (index == 1));
					self.path_2:setEnable(not (index == 3));
				else
					self.path_1:setEnable(true);
					self.path_2:setEnable(true);
				end
			else
				local map, next_idx = DataCenter.expeditionData:getStageInfo(data.next_id);
				if cur_state == 1 and data.stage == cur_stage - 1 then
					self:updatePath(data.map, index, map, cur_location);
				else
					self:updatePath(data.map, index, map, next_idx);
				end
			end
		else
			self.path_1:setEnable(false);
			self.path_2:setEnable(false);
		end

		self.baseIcon:setEnable(eventId == passEventId);
		self.baseIcon.colorStr = Lua_ColorDefine.transColorStr("FFFFFF")
		self.path_1.colorStr = Lua_ColorDefine.transColorStr("FFFFFF")
		self.path_2.colorStr = Lua_ColorDefine.transColorStr("FFFFFF")
		self.icon.colorStr = Lua_ColorDefine.transColorStr("FFFFFF")
		if self.modelEffImg then
			self.modelEffImg.colorStr = Lua_ColorDefine.transColorStr("FFFFFF")
		end
	else
		if data.stage == 7 then
			self.path_1:setEnable(not (index == 1));
			self.path_2:setEnable(not (index == 2));
		else
			if data.map == 3 then
				if data.stage == cur_stage and cur_state == 1 then
					self.path_1:setEnable(not (index == 1) and index == cur_location);
					self.path_2:setEnable(not (index == 3) and index == cur_location);
				else
					self.path_1:setEnable(not (index == 1));
					self.path_2:setEnable(not (index == 3));
				end
			else
				if data.stage == cur_stage and cur_state == 1 then
					self.path_1:setEnable(index == cur_location);
					self.path_2:setEnable(index == cur_location);
				else
					self.path_1:setEnable(true);
					self.path_2:setEnable(true);
				end
			end
		end

		local canClick, canOperate, iconName, modelName, starNum = self:getInfo(data, index, self.eventData);
		self.canClick = canClick;
		self.canOperate = canOperate;
		if not strIsNullOrEmpty(iconName) then
			self:showIcon(iconName)
			self:showModel(nil)
		elseif not strIsNullOrEmpty(modelName) then
			self:showIcon(nil)
			self:showModel(modelName)
		else
			self:showIcon(nil)
			self:showModel(nil)
		end
		self:showStar(starNum)

		if self.canOperate then
			self.baseIcon.colorStr = Lua_ColorDefine.transColorStr("FFFFFF")
			self.icon.colorStr = Lua_ColorDefine.transColorStr("FFFFFF")
			if self.modelEffImg then
				self.modelEffImg.colorStr = Lua_ColorDefine.transColorStr("FFFFFF")
			end
		else
			self.baseIcon.colorStr = Lua_ColorDefine.transColorStr("C8C8C8")
			self.icon.colorStr = Lua_ColorDefine.transColorStr("C8C8C8")
			if self.modelEffImg then
				self.modelEffImg.colorStr = Lua_ColorDefine.transColorStr("C8C8C8")
			end
		end
		self.path_1.colorStr = Lua_ColorDefine.transColorStr("C8C8C8")
		self.path_2.colorStr = Lua_ColorDefine.transColorStr("C8C8C8")
	end
end

-- canClick, canOperate, icon_name, model_name, starNum
function Lua_ExpeditionSingleItem:getInfo(data, index, eventData)
	local cur_stage = DataCenter.expeditionData.cur_stage;
	local cur_location = DataCenter.expeditionData.cur_location;
	local cur_state = DataCenter.expeditionData.cur_state; -- 0：无操作 1：操作中
	if cur_state == 0 then
		if data.stage == cur_stage + 1 then
			local canOperate = false;
			local list = data.can_select_pos[cur_location];
			if list ~= nil then
				for i = 1, #list do
					if list[i] == index then
						canOperate = true;
					end
				end
			end
			self.arrow:setEnable(canOperate);
			return true, canOperate, eventData.icon_name, eventData.model_name, eventData.star
		elseif data.stage == cur_stage + 2 then
			if data.next_id ~= nil and data.next_id > 0 then -- 门要等全层奖励领取后才可显示
				return true, false, eventData.icon_name, eventData.model_name, eventData.star
			end
		else
			if eventData.show_model == 1 then
				return true, false, eventData.icon_name, eventData.model_name, eventData.star
			end
		end
	elseif cur_state == 1 then
		if data.stage == cur_stage then
			if index == cur_location then
				self.arrow:setEnable(true);
				if data.need_buff == 1 and DataCenter.expeditionData.buff_state == 1 then
					return true, true, "ui_bjyz_icon_00"..(eventData.star + 2), eventData.model_name, 0
				else
					return true, true, eventData.icon_name, eventData.model_name, eventData.star
				end
			else
				self.baseIcon:setEnable(false);
			end
		elseif data.stage == cur_stage + 1 then
			return true, false, eventData.icon_name, eventData.model_name, eventData.star
		else
			if eventData.show_model == 1 then
				return true, false, eventData.icon_name, eventData.model_name, eventData.star
			end
		end
	end
	return false, false, nil, nil, 0
end

function Lua_ExpeditionSingleItem:updatePath(curMap, curIdx, nextMap, nextIdx)
	-- print(self.data.id, curMap, curIdx, nextMap, nextIdx)
	if curMap == 3 then -- nextMap是2
		if curIdx == 1 then
			self.path_1:setEnable(false);
			self.path_2:setEnable(nextIdx == 1);
		elseif curIdx == 2 then
			self.path_1:setEnable(nextIdx == 1);
			self.path_2:setEnable(nextIdx == 2);
		else
			self.path_1:setEnable(nextIdx == 2);
			self.path_2:setEnable(false);						
		end
	elseif curMap == 2 then
		if nextMap == 1 then
			if curIdx == 1 then
				self.path_1:setEnable(false);
				self.path_2:setEnable(true);
			else
				self.path_1:setEnable(true);
				self.path_2:setEnable(false);
			end
		else
			if curIdx == 1 then -- nextMap是3
				self.path_1:setEnable(nextIdx == 1);
				self.path_2:setEnable(nextIdx == 2);
			else
				self.path_1:setEnable(nextIdx == 2);
				self.path_2:setEnable(nextIdx == 3);
			end
		end
	else
		if self["path_"..nextIdx] then
			self["path_"..nextIdx]:setEnable(true);
		end
	end
end

function Lua_ExpeditionSingleItem:showIcon(value)
	if strIsNullOrEmpty(value) then
		self.icon:setEnable(false);
	else
		self.icon:setEnable(true);
		self.icon:setAltas("expedition_atlas_3", value);
		self.icon:resetSize();
	end
end

function Lua_ExpeditionSingleItem:showModel(value)
	if strIsNullOrEmpty(value) then
		if self.modelEffImg then
			self.modelEffImg:setEnable(false)
		end
	else
		if self.modelEffImg == nil then
			self.modelEffImg = UICreate.createModelEffImg(self.content, nil, nil, 0, 40, 0, 0)
			self.modelEffImg.siblingIndex = self.icon.siblingIndex
			self.modelEffImg:setScale(0.2, 0.2, 0.2)
			self.modelEffImg:setCamField(1, 1, 100, true)
			self.modelEffImg:setCamPos(0, 1, -10)
			self.modelEffImg:setModelEffDir(180)
			self.modelEffImg.canRot = false
		end
		self.modelEffImg:setEnable(true)
		self.modelEffImg:setUrl("/model/"..value, value);
	end
end

function Lua_ExpeditionSingleItem:showStar(num)
	if self.starArr == nil then
		self.starArr = Array();
	end
	local len = self.starArr:getSize();
	num = num == nil and 0 or num;
	local maxLen = num > len and num or len;
	local star;
	local w = num * 30;
    w = - w / 2 + 30 / 2;
    local posX;
	for i = 1, maxLen do
		star = self.starArr[i];
		if i > num then
			if star ~= nil then
				star:setEnable(false);
			end
		else
			if star == nil then
				star = UICreate.createUIAtlasImage(self.content, nil, nil, 0, 0, 0, 0);
				self.starArr:add(star);
			else
				star:setEnable(true);
			end
			posX = ((i - 1) % num) * 30 + w;
			star:setLocation(posX, 0, 0);
			star:setAltas("common_altas_1", "ui_common_label_11");
		end
	end
end

function Lua_ExpeditionSingleItem:onPressClick()
	local data = DataCenter.expeditionData;
	local sub_times = DataCenter.expeditionUtil:getConstConfig("sub_times", 1, 0) * 60;
	if self.data == nil or self.index == nil or self.eventData == nil or (data.left_sec - sub_times) <= 0 then
		OperateAlert.showLangValue(330036);
		return;
	end

	if not self.canClick then
		return;
	end

	if self.clickTime ~= nil and getTime() - self.clickTime < 0.3 then
		OperateAlert.showLangValue(10031);
		return;
	end
	self.clickTime = getTime();

	-- 选择BUFF
	if self.data.stage == data.cur_stage and self.data.need_buff == 1 and data.buff_state == 1 then
		Lua_WindowUtil.openWin("Lua_ExpeditionBuffChooseWindow", Lua_WinParam.ACTION_OPEN);
		return;
	end

	if self.eventData.type == 6 then
		-- 选择难度
		local level = DataCenter.expeditionUtil:getConstConfig("difficult_param", 1, 0);
		local force = DataCenter.expeditionUtil:getConstConfig("difficult_force", 1, 0);
		if self.data.difficulty ~= nil and (data.role_level >= level or data.force >= force) then
			Lua_WindowUtil.openWin("Lua_ExpeditionDifficultyWindow", Lua_WinParam.ACTION_OPEN, { stageId = self.data.id, index = self.index });
		else
			Lua_MsgUtil.callFunc("EXPEDITION_GOTO_NEXT", self.data);
		end
		return;
	end

	if self.eventData.operate == 1 then
		Lua_WindowUtil.openWin(self.eventData.param, Lua_WinParam.ACTION_OPEN, { canOperate = self.canOperate, stageId = self.data.id, index = self.index });
	elseif self.eventData.operate == 2 then
		if self.canOperate then
			Lua_MsgUtil.callFunc(self.eventData.param, self.data);
		else
			if self.eventData.type == 7 then
				Lua_ProxyManager.getProxy("Lua_ExpeditionProxy"):sCheckBox();
			end
		end
	end
end