checkRequire("Lua_ExpeditionHeroGridItem");
Lua_ExpeditionChallengeWindow = class("Lua_ExpeditionChallengeWindow", Lua_Window);
function Lua_ExpeditionChallengeWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_ExpeditionChallengeWindow";
	self.skinName = "ExpeditionChallengeWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_ExpeditionChallengeWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.titleName:setEnable(false)
	self.titleDeco_1:setEnable(false)
	self.titleDeco_2:setEnable(false)

	self.leftAvatar = Lua_AvatarItem.new(self.content);
	self.leftAvatar:setLocation(-290, 326, 0);
	self.leftAvatar:setScale(0.55, 0.55, 1);

	self.rightAvatar = Lua_AvatarItem.new(self.content);
	self.rightAvatar:setLocation(290, 326, 0);
	self.rightAvatar:setScale(0.55, 0.55, 1);

	self.leftPanel = Lua_HeroGridViewPanel.new(self.content, 1, 0, Lua_ExpeditionHeroGridItem);
	self.leftPanel:setLocation(-178, 153, 0);
	self.leftPanel:setItemSpacing(12, 10);
	self.leftPanel:setCanClick(true);

	self.rightPanel = Lua_HeroGridViewPanel.new(self.content, 1, 2, Lua_ExpeditionHeroGridItem);
	self.rightPanel:setLocation(178, 153, 0);
	self.rightPanel:setItemSpacing(12, 10);
	self.rightPanel:setCanClick(true);

    self.leftArtifactSkill = Lua_SkillIconItem.new(self.content);
    self.leftArtifactSkill:setLocation(-285, -125, 0);
    self.leftArtifactSkill:setScale(0.6, 0.6, 0.6);
    self.leftArtifactSkill:setCanClick(true);

	self.rightArtifactSkill = Lua_SkillIconItem.new(self.content);
	self.rightArtifactSkill:setLocation(285, -125, 0);
	self.rightArtifactSkill:setScale(0.6, 0.6, 0.6);
	self.rightArtifactSkill:setCanClick(true);

	self.cbSkip:setEnable(false);
	self.cbSkip:addBoxChange(self, self.onSkipChange);
	self.btnLayOut:addClickFuntion(self, self.onBtnLayOutClick);
	self.btnChallenge:addClickFuntion(self, self.onBtnChallengeClick);

	self:addLuaEvent("EXPEDITION_CHALLENGE_INFO", self, self.updateShowInfo);
	self:addLuaEvent("UPDATE_HERO_LINEUP_INFO", self, self.onLineupUpdate);
end

function Lua_ExpeditionChallengeWindow:dispose()
	DataCenter.preLoadData:removeBySign("Lua_ExpeditionLineupWindow", self, self.onSceneShow);
	if self.leftAvatar ~= nil then
		self.leftAvatar:dispose();
		self.leftAvatar = nil;
	end
	if self.rightAvatar ~= nil then
		self.rightAvatar:dispose();
		self.rightAvatar = nil;
	end
	if self.leftPanel ~= nil then
		self.leftPanel:dispose();
		self.leftPanel = nil;
	end
	if self.rightPanel ~= nil then
		self.rightPanel:dispose();
		self.rightPanel = nil;
	end
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.leftArtifactSkill ~= nil then
		self.leftArtifactSkill:dispose();
		self.leftArtifactSkill = nil;
	end
	if self.rightArtifactSkill ~= nil then
		self.rightArtifactSkill:dispose();
		self.rightArtifactSkill = nil;
	end
	self.msg = nil;
	self.eventData = nil;
	self:superCall("dispose");
end

function Lua_ExpeditionChallengeWindow:showWin(param)
	self:superCall("showWin", param);

	local eventId = DataCenter.expeditionData:getLatticeEvent(param.stageId, param.index);
	if eventId == 8 then
		self.prompt:setLangValue(330042);
	else
		self.prompt:setLangValue(330017);
	end
	self.eventData = DataCenter.expeditionUtil:getLatticeInfo(eventId);
	self.titleName:setAltas("expedition_atlas_1", self.eventData.title_sprite);
	self.titleName:resetSize();

	local one_key_skip = DataCenter.expeditionUtil:getConstConfig("one_key_skip", 1);
	self.cbSkip:setEnable(param.canOperate == true and DataCenter.funcOpenData:isOpened(one_key_skip));
	self.cbSkip.selected = DataCenter.expeditionData.one_key_skip == 1;
	self.btnLayOut:setEnable(param.canOperate == true);
	self.btnChallenge:setEnable(param.canOperate == true);
	self:getServerInfo();
end

function Lua_ExpeditionChallengeWindow:updateShowInfo(msg)
	self.msg = msg;
	if msg == nil then
		return;
	end

	self.leftAvatar:setRoleId(msg.self_player.id);
	self.leftAvatar:setRoleDressUp(msg.self_player.dress_info);
	self.leftName.text = msg.self_player.name;
	self.leftForce.text = LanUtil.formateStr(10039, tostring(msg.self_player.force));

	self.rightAvatar:setRoleDressUp(msg.def_player.dress_info);
	self.rightName.text = msg.def_player.name;
	self.rightForce.text = LanUtil.formateStr(10039, tostring(msg.def_player.force));
	self.rightForce:resetSize();
	self.forceIcon_2:setLocation(self.rightForce.posX - self.rightForce.width, 309.5, 0);

	local blueCount = 0;
	local purpleCount = 0;
	local orangeCount = 0;
	if msg.buff_list ~= nil then
		local config;
		for i = 1, #msg.buff_list do
			config = DataCenter.expeditionUtil:getBuffInfo(msg.buff_list[i]);
			if config ~= nil then
				if config.color == 3 then
					blueCount = blueCount + 1;
				elseif config.color == 4 then
					purpleCount = purpleCount + 1;
				elseif config.color == 5 then
					orangeCount = orangeCount + 1;
				end
			end
		end
	end
	self.blueCount.text = blueCount;
	self.purpleCount.text = purpleCount;
	self.orangeCount.text = orangeCount;
	self.forceAdd.text = LanUtil.formateStr(330018, tostring(msg.force_add));
	
	self.leftPanel:setStandType(msg.self_stand_type);
	self.leftPanel:setDataByProto(msg.self_hero_list);
	self.rightPanel:setDataByProto(msg.def_hero_list);

	if msg.self_player.artifact_id > 0 then
		local vo = DataCenter.artifactUtil:getArtifactVoById(msg.self_player.artifact_id);
		self.leftArtifact.text = LanUtil.formateStr(330041, vo.name);
		self.leftArtifactSkill:setSkillId(msg.self_artifact_skill_id);
		self.leftArtifactSkill:setLock(false);
	else
		self.leftArtifact.text = LanUtil.formateStr(330041, LanUtil.getValue(20));
		self.leftArtifactSkill:setSkillId(nil);
		self.leftArtifactSkill:setLock(true);
	end
	
	if msg.def_player.artifact_id > 0 then
		local vo = DataCenter.artifactUtil:getArtifactVoById(msg.def_player.artifact_id);
		self.rightArtifact.text = LanUtil.formateStr(330041, vo.name);
		self.rightArtifactSkill:setSkillId(msg.def_artifact_skill_id);
		self.rightArtifactSkill:setLock(false);
	else
		self.rightArtifact.text = LanUtil.formateStr(330041, LanUtil.getValue(20));
		self.rightArtifactSkill:setSkillId(nil);
		self.rightArtifactSkill:setLock(true);
	end

	if self.itemList == nil then
		local num = msg.reward_items == nil and 0 or #msg.reward_items;
		local itemW = 112 * 0.7;
		local width = num * itemW + (num - 1) * 15;
		self.itemList = Lua_DragList.new(self.content, width, itemW, Lua_AxisDefine.Horizontal);
		self.itemList:setLocation(25, -223);
		self.itemList:setListCell(Lua_ExpeditionChallengeItem, itemW, itemW, 1);
		self.itemList:setCellSpacing(15, 0);
	end
	self.itemList:setArrayData(msg.reward_items);
end

function Lua_ExpeditionChallengeWindow:onLineupUpdate(lineup_type)
	if lineup_type == Lua_HeroUtil.LINEUP_EXPEDITION then
		self:getServerInfo();
	end
end

function Lua_ExpeditionChallengeWindow:getServerInfo()
	if self.showData == nil then
		return;
	end
	Lua_ProxyManager.getProxy("Lua_ExpeditionProxy"):sChallengeInfo(self.showData.stageId, self.showData.index);
end

function Lua_ExpeditionChallengeWindow:onSkipChange(bChange)
	Lua_ProxyManager.getProxy("Lua_ExpeditionProxy"):sSkipFight(bChange == true and 1 or 0);
end

function Lua_ExpeditionChallengeWindow:onBtnLayOutClick(go)
	if self.msg == nil then
		return;
	end
	local sceneId = DataCenter.heroLineupData:getFightLineupSceneId(Lua_FightDefine.TEMPLATE_ID_EXPEDITION);
	DataCenter.preLoadData:preShowScene("Lua_ExpeditionLineupWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onSceneShow, nil, sceneId, 0);
end

function Lua_ExpeditionChallengeWindow:onSceneShow(param)
	Lua_WindowUtil.openWin("Lua_ExpeditionLineupWindow", Lua_WinParam.ACTION_OPEN, { name = self.eventData.name, msg = self.msg });
end

function Lua_ExpeditionChallengeWindow:onBtnChallengeClick(go)
	if self.showData == nil then
		return;
	end

	local serverLineupDic = DataCenter.heroLineupData:getServerLineupDic(Lua_HeroUtil.LINEUP_EXPEDITION);
	local num = table.length(serverLineupDic[1]);
	if num <= 0 then --阵容中至少上阵一名英雄
		OperateAlert.showLangValue(126307);
		return;
	end

	local stand_type = DataCenter.heroLineupData:getServerStandType(Lua_HeroUtil.LINEUP_EXPEDITION, 1);
	local position_list = DataCenter.heroLineupUtil:getStandInfoByType(stand_type).position_list;
	local len = #position_list;
	if num < len and DataCenter.expeditionData:checkPackHaveHero(serverLineupDic, 1) then
		local tipsData = { font_size = 28, des = LanUtil.getValue(126312), btnType = 1, owner = self, sureFun = self.onSureFun };
		Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
		return;
	end

	self:onSureFun();
end

function Lua_ExpeditionChallengeWindow:onSureFun()
	Lua_ProxyManager.getProxy("Lua_FightProxy"):sStartFight(Lua_FightDefine.TEMPLATE_ID_EXPEDITION, self.showData.stageId * 100 + self.showData.index);
	self:hide();
end




















Lua_ExpeditionChallengeItem = class("Lua_ExpeditionChallengeItem", Lua_ItemIconCell);
function Lua_ExpeditionChallengeItem:buildShowItem()
	self:superCall("buildShowItem");
	self.itemIcon:setScale(0.7, 0.7, 0.7);
end